@@ -1,13 +1,10 @@
 /******************************************************************************
 *   KBlocks, a falling blocks game by KDE                                     *
-*   Copyright (C) 2010-2021 Mauricio Piacentini <mauricio@tabuleiro.com>      *
+*   SPDX-FileCopyrightText: 2010-2021 Mauricio Piacentini <mauricio@tabuleiro.com>      *
 *                           Zhongjie Cai <squall.leonhart.cai@gmail.com>      *
 *                           Julian Helfferich <julian.helfferich@mailbox.org> *
 *                                                                             *
-*   This program is free software; you can redistribute it and/or modify      *
-*   it under the terms of the GNU General Public License as published by      *
-*   the Free Software Foundation; either version 2 of the License, or         *
-*   (at your option) any later version.                                       *
+*   SPDX-License-Identifier: GPL-2.0-or-later
 ******************************************************************************/
 #include <QResizeEvent>
 
@@ -33,11 +30,20 @@ KBlocksView::~KBlocksView()
 {
 }
 
+void KBlocksView::loadTheme(const KgTheme *theme)
+{
+    SceneInterface* s = dynamic_cast<SceneInterface*>(scene());
+    if (s) {
+        s->loadTheme(theme);
+    }
+    fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
+}
+
 void KBlocksView::settingsChanged()
 {
     SceneInterface* s = dynamic_cast<SceneInterface*>(scene());
     if (s) {
-        s->readSettings(size());
+        s->readSettings();
     }
     fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
 }
